@@ -56,23 +56,6 @@ class DynamoDBGlobalConfiguration:
     single_table_sk_attr_name: str
     single_table_inverse_index_properties: dict
 
-    def __post_init__(self):  # Connect to the database if ddb is None
-        if self.ddb is None:
-            try:
-                if self.use_aws_cli_credentials:
-                    self.ddb = boto3.resource("dynamodb")
-                else:
-                    self.ddb = boto3.resource(
-                        "dynamodb",
-                        endpoint_url=self.access_params["endpoint_url"],
-                        region_name=self.access_params["region_name"],
-                        aws_access_key_id=self.access_params["aws_access_key_id"],
-                        aws_secret_access_key=self.access_params["aws_secret_access_key"],
-                    )
-            except Exception as ex:
-                print(ex)
-                raise ConnectionRefusedError("Not able to connect to DynamoDB")
-
     @classmethod
     def get_instance(
         cls,
@@ -162,6 +145,24 @@ class DynamoDBGlobalConfiguration:
     def is_instantiated(cls):
         return cls._instance is not None
 
+    def get_connection(self):
+        if self.ddb is None: # Connect to the database if ddb is None
+            try:
+                if self.use_aws_cli_credentials:
+                    self.ddb = boto3.resource("dynamodb")
+                else:
+                    self.ddb = boto3.resource(
+                        "dynamodb",
+                        endpoint_url=self.access_params["endpoint_url"],
+                        region_name=self.access_params["region_name"],
+                        aws_access_key_id=self.access_params["aws_access_key_id"],
+                        aws_secret_access_key=self.access_params["aws_secret_access_key"],
+                    )
+            except Exception as ex:
+                print(ex)
+                raise ConnectionRefusedError("Not able to connect to DynamoDB")
+        return self.ddb
+
 
 ###### ---------- Global parameters ---------- ######
 
@@ -580,7 +581,7 @@ class DynamoCrudRepository(CrudRepository):
         global_values = DynamoDBGlobalConfiguration.get_instance()
         # For a single table design, define the table name as a global parameter,
         # if the table name is not set in the global parameters, will use the entity class table name
-        self.ddb = global_values.ddb
+        self.ddb = global_values.get_connection()
         if dynamo_table_name is not None:
             self.table_name = dynamo_table_name
         elif hasattr(entity_type, "dynamo_table_name") and entity_type.dynamo_table_name() is not None:
@@ -705,52 +706,82 @@ class DynamoCrudRepository(CrudRepository):
         else:
             return self.remove_by_id(getattr(to_delete, to_delete.dynamo_id()))
 
+    def item_attr2_instance_attr(self, item_attr_val, instance_attr_name: str, instance_attr_type: type):
+        if ConstantString.ITEM2OBJ_CONV.value in self.map_dict[instance_attr_name]:
+            return self.map_dict[instance_attr_name][ConstantString.ITEM2OBJ_CONV.value](item_attr_val)
+        # convert to string then to the actual type to make sure the conversion will work
+        elif issubclass(instance_attr_type, (int, float, Decimal)):
+            return instance_attr_type(str(item_attr_val))
 
+        elif issubclass(instance_attr_type, (bytes, bool)):  # Perform a direct conversion
+            return instance_attr_type(item_attr_val)
+
+        elif issubclass(instance_attr_type, (dict, list)):  # json
+            return json.loads(item_attr_val)
+
+        elif issubclass(instance_attr_type, Enum):  # Enum
+            return instance_attr_type[item_attr_val]
+
+        elif issubclass(instance_attr_type, str):
+            return str(item_attr_val)
+
+        # Use the iso format for storing datetime as strings
+        elif issubclass(
+                instance_attr_type, (datetime.date, datetime.time, datetime.datetime)
+        ):
+            return instance_attr_type.fromisoformat(item_attr_val)
+
+        elif issubclass(instance_attr_type, object):  # objects in general are pickled
+            return bytes(item_attr_val)
+
+        else:  # No special case, use a simple cast, probably will never be reached
+            return instance_attr_type(item_attr_val)
 
     def item2instance(self, item):
-        entity_instance = self.entity_type()
-
+        #entity_instance = self.entity_type()
+        instance_attributes = {}
         for fl in fields(self.entity_type):
             item_attr_name = self.map_dict[fl.name][ConstantString.ITEM_ATTR_NAME.value]
             if item_attr_name in item:
-                if ConstantString.ITEM2OBJ_CONV.value in self.map_dict[fl.name]:
-                    setattr(
-                        entity_instance,
-                        fl.name,
-                        self.map_dict[fl.name][ConstantString.ITEM2OBJ_CONV.value](item[item_attr_name]),
-                    )
-                # convert to string then to the actual type to make sure the conversion will work
-                elif issubclass(fl.type, (int, float, Decimal)):
-                    setattr(entity_instance, fl.name, fl.type(str(item[item_attr_name])))
-
-                elif issubclass(fl.type, (bytes, bool)):  # Perform a direct conversion
-                    setattr(entity_instance, fl.name, fl.type(item[item_attr_name]))
-
-                elif issubclass(fl.type, (dict, list)):  # json
-                    setattr(entity_instance, fl.name, json.loads(item[item_attr_name]))
-
-                elif issubclass(fl.type, Enum):  # Enum
-                    setattr(entity_instance, fl.name, fl.type[item[item_attr_name]])
-
-                elif issubclass(fl.type, str):
-                    setattr(entity_instance, fl.name, str(item[item_attr_name]))
-
-                # Use the iso format for storing datetime as strings
-                elif issubclass(
-                    fl.type, (datetime.date, datetime.time, datetime.datetime)
-                ):
-                    setattr(
-                        entity_instance, fl.name, fl.type.fromisoformat(item[item_attr_name])
-                    )
-
-                elif issubclass(fl.type, object):  # objects in general are pickled
-                    setattr(
-                        entity_instance, fl.name, pickle.loads(bytes(item[item_attr_name]))
-                    )
-
-                else:  # No special case, use a simple cast, probably will never be reached
-                    setattr(entity_instance, fl.name, fl.type(item[item_attr_name]))
-
+                instance_attributes[fl.name] = self.item_attr2_instance_attr(item[item_attr_name], fl.name, fl.type)
+                # if ConstantString.ITEM2OBJ_CONV.value in self.map_dict[fl.name]:
+                #     setattr(
+                #         entity_instance,
+                #         fl.name,
+                #         self.map_dict[fl.name][ConstantString.ITEM2OBJ_CONV.value](item[item_attr_name]),
+                #     )
+                # # convert to string then to the actual type to make sure the conversion will work
+                # elif issubclass(fl.type, (int, float, Decimal)):
+                #     setattr(entity_instance, fl.name, fl.type(str(item[item_attr_name])))
+                #
+                # elif issubclass(fl.type, (bytes, bool)):  # Perform a direct conversion
+                #     setattr(entity_instance, fl.name, fl.type(item[item_attr_name]))
+                #
+                # elif issubclass(fl.type, (dict, list)):  # json
+                #     setattr(entity_instance, fl.name, json.loads(item[item_attr_name]))
+                #
+                # elif issubclass(fl.type, Enum):  # Enum
+                #     setattr(entity_instance, fl.name, fl.type[item[item_attr_name]])
+                #
+                # elif issubclass(fl.type, str):
+                #     setattr(entity_instance, fl.name, str(item[item_attr_name]))
+                #
+                # # Use the iso format for storing datetime as strings
+                # elif issubclass(
+                #     fl.type, (datetime.date, datetime.time, datetime.datetime)
+                # ):
+                #     setattr(
+                #         entity_instance, fl.name, fl.type.fromisoformat(item[item_attr_name])
+                #     )
+                #
+                # elif issubclass(fl.type, object):  # objects in general are pickled
+                #     setattr(
+                #         entity_instance, fl.name, pickle.loads(bytes(item[item_attr_name]))
+                #     )
+                #
+                # else:  # No special case, use a simple cast, probably will never be reached
+                #     setattr(entity_instance, fl.name, fl.type(item[item_attr_name]))
+        entity_instance = self.entity_type(**instance_attributes)
         return entity_instance
 
     def find_by_keys(self, keys: Union[dict, list]):
